# mandato

[![Tests](https://github.com/kairix-dev/mandato/workflows/Tests/badge.svg)](https://github.com/kairix-dev/mandato/actions)
[![Python](https://img.shields.io/pypi/pyversions/mandato.svg)](https://pypi.org/project/mandato/)
[![PyPI version](https://badge.fury.io/py/mandato.svg)](https://badge.fury.io/py/mandato)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/)


ORMA's Brother.
